"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/es.array.find.js");

require("core-js/modules/es.object.to-string.js");

require("core-js/modules/es.array.flat-map.js");

require("core-js/modules/es.array.unscopables.flat-map.js");

require("core-js/modules/es.array.map.js");

require("core-js/modules/es.array.join.js");

require("core-js/modules/es.array.concat.js");

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.string.match.js");

require("core-js/modules/web.dom-collections.for-each.js");

require("core-js/modules/es.object.assign.js");

require("core-js/modules/es.array.filter.js");

require("core-js/modules/es.function.name.js");

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _global = _interopRequireDefault(require("global"));

var _ansiColors = require("ansi-colors");

var _register = _interopRequireDefault(require("babel-plugin-require-context-hook/register"));

var _globalJsdom = _interopRequireDefault(require("global-jsdom"));

var _plur = _interopRequireDefault(require("plur"));

var _reactElementToJsxString = _interopRequireDefault(require("react-element-to-jsx-string"));

var _coreCommon = require("@storybook/core-common");

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable global-require, no-console, import/no-dynamic-require, @typescript-eslint/no-var-requires */
// Based on https://github.com/storybookjs/storybook/blob/next/addons/storyshots/storyshots-core/src/frameworks/configure.ts
(0, _register.default)();
(0, _globalJsdom.default)();

var storybook = require('@storybook/react');

var isFile = function isFile(file) {
  try {
    return _fs.default.lstatSync(file).isFile();
  } catch (err) {
    return false;
  }
};

var extensions = ['ts', 'tsx', 'js', 'jsx'];

var resolveFile = function resolveFile(configDir, filenames) {
  return filenames.flatMap(function (filename) {
    return extensions.map(function (ext) {
      return _path.default.join(configDir, "".concat(filename, ".").concat(ext));
    });
  }).find(isFile) || false;
};

var getPreviewFile = function getPreviewFile(configDir) {
  return resolveFile(configDir, ['preview', 'config']);
};

var getMainFile = function getMainFile(configDir) {
  return resolveFile(configDir, ['main']);
};

var getConfigPathParts = function getConfigPathParts(input) {
  var configDir = _path.default.resolve(input);

  if (_fs.default.lstatSync(configDir).isDirectory()) {
    var output = {};
    var preview = getPreviewFile(configDir);
    var main = getMainFile(configDir);

    if (preview) {
      output.preview = preview;
    }

    if (main) {
      var _require = require(main),
          _require$stories = _require.stories,
          stories = _require$stories === void 0 ? [] : _require$stories;

      var workingDir = process.cwd();
      output.stories = stories.map(function (entry) {
        var specifier = (0, _coreCommon.normalizeStoriesEntry)(entry, {
          configDir: configDir,
          workingDir: workingDir
        });

        var _toRequireContext = (0, _coreCommon.toRequireContext)(specifier),
            basePath = _toRequireContext.path,
            recursive = _toRequireContext.recursive,
            match = _toRequireContext.match; // eslint-disable-next-line no-underscore-dangle


        return _global.default.__requireContext(workingDir, basePath, recursive, match);
      });
    }

    return output;
  }

  return {
    preview: configDir
  };
};

var configure = function configure(options) {
  var configDir = options.configDir;

  var _getConfigPathParts = getConfigPathParts(configDir),
      preview = _getConfigPathParts.preview,
      stories = _getConfigPathParts.stories;

  if (preview) {
    var _require2 = require(preview),
        parameters = _require2.parameters,
        decorators = _require2.decorators,
        globals = _require2.globals,
        globalTypes = _require2.globalTypes,
        argsEnhancers = _require2.argsEnhancers,
        argTypesEnhancers = _require2.argTypesEnhancers;

    if (decorators) {
      decorators.forEach(function (decorator) {
        return storybook.addDecorator(decorator);
      });
    }

    if (parameters || globals || globalTypes) {
      storybook.addParameters(Object.assign(Object.assign({}, parameters), {}, {
        globals: globals,
        globalTypes: globalTypes
      }));
    }

    if (argsEnhancers) {
      argsEnhancers.forEach(function (enhancer) {
        return storybook.addArgsEnhancer(enhancer);
      });
    }

    if (argTypesEnhancers) {
      argTypesEnhancers.forEach(function (enhancer) {
        return storybook.addArgTypesEnhancer(enhancer);
      });
    }
  }

  if ((stories == null ? void 0 : stories.length) > 0) {
    storybook.configure(stories, false, false);
  }
};

var _default = function _default(configDir, _ref) {
  var outFile = _ref.outFile;
  configure({
    configDir: configDir
  });
  var snippets = storybook.raw().map(function (_ref2) {
    var group = _ref2.kind,
        name = _ref2.name,
        storyFn = _ref2.storyFn,
        _ref2$parameters = _ref2.parameters;
    _ref2$parameters = _ref2$parameters === void 0 ? {} : _ref2$parameters;
    var playroom = _ref2$parameters.playroom;

    var _getOptions = (0, _utils.getOptions)(playroom),
        disable = _getOptions.disable,
        reactElementToJSXStringOptions = _getOptions.reactElementToJSXStringOptions;

    if (disable) {
      return undefined;
    }

    console.log("Generating ".concat((0, _ansiColors.yellow)([group, name].join('/')), " snippet..."));
    var code = (0, _reactElementToJsxString.default)(storyFn(), reactElementToJSXStringOptions);
    return {
      group: group,
      name: name,
      code: code
    };
  }).filter(Boolean);

  _fs.default.writeFileSync(_path.default.resolve(process.cwd(), outFile), JSON.stringify(snippets, null, 2));

  console.log("\n".concat(snippets.length, " ").concat((0, _plur.default)('snippet', snippets.length), " generated."));
};

exports.default = _default;